==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/RequiredOperationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredOperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperation;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.InterfaceOperationInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.InterfaceOperationInvocationSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class RequiredOperationSetImpl extends InstanceSet<RequiredOperationSet,RequiredOperation> implements RequiredOperationSet {

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setName( m_Name );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setDialect( m_Dialect );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setDescrip( m_Descrip );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setAction_Semantics_internal( m_Action_Semantics_internal );
    }


    // selections
    @Override
    public RequiredExecutablePropertySet R4502_is_a_RequiredExecutableProperty() throws XtumlException {
        RequiredExecutablePropertySet requiredexecutablepropertyset = new RequiredExecutablePropertySetImpl();
        for ( RequiredOperation requiredoperation : this ) requiredexecutablepropertyset.add( requiredoperation.R4502_is_a_RequiredExecutableProperty() );
        return requiredexecutablepropertyset;
    }
    @Override
    public InterfaceOperationInvocationSet R657_InterfaceOperationInvocation() throws XtumlException {
        InterfaceOperationInvocationSet interfaceoperationinvocationset = new InterfaceOperationInvocationSetImpl();
        for ( RequiredOperation requiredoperation : this ) interfaceoperationinvocationset.addAll( requiredoperation.R657_InterfaceOperationInvocation() );
        return interfaceoperationinvocationset;
    }
    @Override
    public RequiredOperationBodySet R685_RequiredOperationBody() throws XtumlException {
        RequiredOperationBodySet requiredoperationbodyset = new RequiredOperationBodySetImpl();
        for ( RequiredOperation requiredoperation : this ) requiredoperationbodyset.add( requiredoperation.R685_RequiredOperationBody() );
        return requiredoperationbodyset;
    }


    @Override
    public RequiredOperation nullElement() {
        return RequiredOperationImpl.EMPTY_REQUIREDOPERATION;
    }

    @Override
    public RequiredOperationSet emptySet() {
      return new RequiredOperationSetImpl();
    }

    @Override
    public RequiredOperationSet value() {
        return this;
    }

    @Override
    public List<RequiredOperation> elements() {
        RequiredOperation[] elements = toArray(new RequiredOperation[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/RequiredOperationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredOperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperation;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.InterfaceOperationInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.InterfaceOperationInvocationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class RequiredOperationSetImpl extends InstanceSet<RequiredOperationSet,RequiredOperation> implements RequiredOperationSet {

    public RequiredOperationSetImpl() {
    }

    public RequiredOperationSetImpl(Comparator<? super RequiredOperation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setId( ref_Id );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setDescrip( m_Descrip );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setName( m_Name );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( RequiredOperation requiredoperation : this ) requiredoperation.setDialect( m_Dialect );
    }


    // selections
    @Override
    public RequiredExecutablePropertySet R4502_is_a_RequiredExecutableProperty() throws XtumlException {
        RequiredExecutablePropertySet requiredexecutablepropertyset = new RequiredExecutablePropertySetImpl();
        for ( RequiredOperation requiredoperation : this ) requiredexecutablepropertyset.add( requiredoperation.R4502_is_a_RequiredExecutableProperty() );
        return requiredexecutablepropertyset;
    }
    @Override
    public InterfaceOperationInvocationSet R657_InterfaceOperationInvocation() throws XtumlException {
        InterfaceOperationInvocationSet interfaceoperationinvocationset = new InterfaceOperationInvocationSetImpl();
        for ( RequiredOperation requiredoperation : this ) interfaceoperationinvocationset.addAll( requiredoperation.R657_InterfaceOperationInvocation() );
        return interfaceoperationinvocationset;
    }
    @Override
    public RequiredOperationBodySet R685_RequiredOperationBody() throws XtumlException {
        RequiredOperationBodySet requiredoperationbodyset = new RequiredOperationBodySetImpl();
        for ( RequiredOperation requiredoperation : this ) requiredoperationbodyset.add( requiredoperation.R685_RequiredOperationBody() );
        return requiredoperationbodyset;
    }


    @Override
    public RequiredOperation nullElement() {
        return RequiredOperationImpl.EMPTY_REQUIREDOPERATION;
    }

    @Override
    public RequiredOperationSet emptySet() {
      return new RequiredOperationSetImpl();
    }

    @Override
    public RequiredOperationSet emptySet(Comparator<? super RequiredOperation> comp) {
      return new RequiredOperationSetImpl(comp);
    }

    @Override
    public RequiredOperationSet value() {
        return this;
    }

    @Override
    public List<RequiredOperation> elements() {
        RequiredOperation[] elements = toArray(new RequiredOperation[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
